<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2007 Tim Lochmueller, Sareen Millet
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

class ux_tslib_cObj extends tslib_cObj {

        /**
         * Returns a <img> tag with the image file defined by $file and processed according to the properties in the TypoScript array.
         * Mostly this function is a sub-function to the IMAGE function which renders the IMAGE cObject in TypoScript. This function is called by "$this->cImage($conf['file'],$conf);" from IMAGE().
         *
         * @param        string                File TypoScript resource
         * @param        array                TypoScript configuration properties
         * @return        string                <img> tag, (possibly wrapped in links and other HTML) if any image found.
         * @access private
         * @see IMAGE()
         */
        function cImage($file,$conf) {
        
        	$this->realURLImage = t3lib_div::makeInstance('tx_flrealurlimage');
        
        
            $this->conf['spaceCharacter'] = $GLOBALS['fl_realurl_image']['defaultDelimiter'];
                 $info = $this->getImgResource($file,$conf['file.']);
                $GLOBALS['TSFE']->lastImageInfo=$info;
                if (is_array($info))        {
                        $info[3] = t3lib_div::png_to_gif_by_imagemagick($info[3]);
                        $GLOBALS['TSFE']->imagesOnPage[]=$info[3];                // This array is used to collect the image-refs on the page...

                        if (!strlen($conf['altText']) && !is_array($conf['altText.']))        {        // Backwards compatible:
                                $conf['altText'] = $conf['alttext'];
                                $conf['altText.'] = $conf['alttext.'];
                        }

                        // Here begins RealURL Image

                        // if there is no alt-attribut for the <img>-tag use the page title
                        if (!$conf['altText'] || trim($conf['altText']) == "")
                            $conf['altText'] = $this->realURLImage->getLangTitle();
                        

                        // generate the attributes for the <img>-tag
                        $altParam = $this->getAltParam($conf);


                        $text = $this->getImageText($conf);


                        // the path to the real image location
                        $img_path = htmlspecialchars(trim(t3lib_div::rawUrlEncodeFP($info[3]))); // Das ist der Pfad, der normal zum Bild fhrt: typo3temp/pics/2305e38d9c.jpg

                        // generate a RealUrl-filename for the picture and set the pair picture - realUrl in the DB
                        if ($img_path != "")
                            $img_path = $this->realURLImage->makeRealURLImgPath($this->encodeTitle($text),$img_path);

                        // generate the <img>-tag
                        $theValue = '<img src="'.htmlspecialchars($GLOBALS['TSFE']->absRefPrefix).$img_path.'" width="'.$info[0].'" height="'.$info[1].'"'.$this->getBorderAttr(' border="'.intval($conf['border']).'"').($conf['params']?' '.$conf['params']:'').($altParam).' />';

                        // Here ends RealURL Image


                        if ($conf['linkWrap'])        {
                                $theValue = $this->linkWrap($theValue,$conf['linkWrap']);
                        } elseif ($conf['imageLinkWrap']) {
                                $theValue = $this->imageLinkWrap($theValue,$info['origFile'],$conf['imageLinkWrap.']);
                        }
                        return $this->wrap($theValue,$conf['wrap']);
                }
        }

        /*******************************
         *
         * Helper functions
         *
         ******************************/
	
	

        /**
         * Convert a title to something that can be used in an page path:
         * - Convert spaces to underscores
         * - Convert non A-Z characters to ASCII equivalents
         * - Convert some special things like the 'ae'-character
         * - Strip off all other symbols
         * Works with the character set defined as "forceCharset"
         *
         * @param        string                Input title to clean
         * @return       string                Encoded title, passed through rawurlencode() = ready to put in the URL.
         * @see rootLineToPath()
         */
        function encodeTitle($title) {

                // Fetch character set:
                $charset = $GLOBALS['TYPO3_CONF_VARS']['BE']['forceCharset'] ? $GLOBALS['TYPO3_CONF_VARS']['BE']['forceCharset'] : $GLOBALS['TSFE']->defaultCharSet;

                // Convert to lowercase:
                $processedTitle = $GLOBALS['TSFE']->csConvObj->conv_case($charset,$title,'toLower');

                // Convert some special tokens to the space character:
                $space = $this->conf['spaceCharacter'] ? $this->conf['spaceCharacter'] : '-';
                $processedTitle = strtr($processedTitle,' -+_',$space.$space.$space.$space);        // convert spaces

                // Convert extended letters to ascii equivalents:
                $processedTitle = $GLOBALS['TSFE']->csConvObj->specCharsToASCII($charset,$processedTitle);

                // Strip the rest...:
                $processedTitle = ereg_replace('[^a-zA-Z0-9\\'.$space.']', $space, $processedTitle);  // replace other characters with $space
                $processedTitle = ereg_replace('\\'.$space.'+',$space,$processedTitle);               // Convert multiple 'spaces' to a single one
                $processedTitle = trim($processedTitle,$space);

                if ($this->conf['encodeTitle_userProc'])        {
                        $params = array(
                                'pObj' => &$this,
                                'title' => $title,
                                'processedTitle' => $processedTitle,
                        );
                        $processedTitle = t3lib_div::callUserFunction($this->conf['encodeTitle_userProc'], $params, $this);
                }
                
                // Return encoded URL:
                return rawurlencode($processedTitle);
        }


	/*
	 * Get the Image Text From a Image configuration
	 *
	 * @return Array Image Conf
	 * @todo stdWarp Funktion not there
	 */
	function getImageText($conf) {
		$text = trim($this->stdWrap($conf['fileName'], $conf['fileName.']));
		if(!$text) $text = trim($this->stdWrap($conf['altText'], $conf['altText.']));
		if(!$text) $text = trim($this->stdWrap($conf['titleText'],$conf['titleText.']));
		if(!$text) $text = trim($this->stdWrap($conf['longdescURL'],$conf['longdescURL.']));
		if(!$text) $text = $GLOBALS['fl_realurl_image']['defaultImageText'];
		
		return $text;
	} # function
} # class
?>